update_address_ban_status

Function update_address_ban_status 

pub fn update_address_ban_status<R, E>(
    address_list: &AddressList,
    result: &ExecutionResult<R, E>,
    applied_settings: &AppliedRequestSettings,
)
where E: CanRetry + Display + Debug,
Ban address in case of retryable error or unban it if it was banned, and the request was successful.