FromInner

Trait FromInner 

pub trait FromInner<R>
where Self: Default,
{ // Required method fn from_inner(inner: R) -> Self; }
Create full wrapping object from inner type, using defaults for fields that cannot be derived from the inner type.

Required Methods

fn from_inner(inner: R) -> Self

Create full wrapping object from inner type, using defaults for fields that cannot be derived from the inner type.

Note this is imprecise conversion and should be avoided outside of tests.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<R> FromInner<R> for ExecutionResponse<R>
where Self: Default,