RequestSettings

Struct RequestSettings 

pub struct RequestSettings {
    pub connect_timeout: Option<Duration>,
    pub timeout: Option<Duration>,
    pub retries: Option<usize>,
    pub ban_failed_address: Option<bool>,
    pub max_decoding_message_size: Option<usize>,
}
DAPI request settings.

There are four levels of settings where each next level can override all previous ones:

  1. Defaults for this library;
  2. crate::DapiClient settings;
  3. crate::DapiRequest-specific settings;
  4. settings for an exact request execution call.

Fields

connect_timeout: Option<Duration>

Timeout for establishing a connection.

timeout: Option<Duration>

Timeout for single request (soft limit).

Note that the total maximum time of execution can exceed (timeout + connect_timeout) * retries as it accounts for internal processing time between retries.

retries: Option<usize>

Number of retries in case of failed requests. If max retries reached, the last error is returned. 1 means one request and one retry in case of error, etc.

ban_failed_address: Option<bool>

Ban DAPI address if node not responded or responded with error.

max_decoding_message_size: Option<usize>

Maximum gRPC response size in bytes (decoding limit).

Implementations

Source

impl RequestSettings

pub const fn default() -> Self

Create empty RequestSettings, which means no overrides will be applied. Actually does the same as Default, but it’s const.

pub fn override_by(self, rhs: RequestSettings) -> Self

Combines two instances of RequestSettings with following rules:

  1. in case of Some and None for one field the Some variant will remain,
  2. in case of two Some variants, right hand side argument will overwrite the value.
pub fn finalize(self) -> AppliedRequestSettings

Fill in settings defaults.