InnerInto

Trait InnerInto 

pub trait InnerInto<T> {
    // Required method
    fn inner_into(self) -> T;
}
Convert inner type without losing additional context information of the wrapper.

Required Methods

fn inner_into(self) -> T

Convert inner type without losing additional context information of the wrapper.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, FE, T, TE> InnerInto<Result<ExecutionResponse<T>, ExecutionError<TE>>> for ExecutionResult<F, FE>
where F: Into<T>, FE: Into<TE>,

Source

impl<F, T> InnerInto<ExecutionError<T>> for ExecutionError<F>
where F: Into<T>,

Source

impl<F, T> InnerInto<ExecutionResponse<T>> for ExecutionResponse<F>
where F: Into<T>,