IntoInner

Trait IntoInner 

pub trait IntoInner<T> {
    // Required method
    fn into_inner(self) -> T;
}
Unwrap wrapped types

Required Methods

fn into_inner(self) -> T

Unwrap the inner type.

This function returns inner type, dropping additional context information. It is lossy operation, so it should be used with caution.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E, I> IntoInner<I> for ExecutionError<E>
where E: Into<I>,

Source

impl<R, E> IntoInner<Result<R, E>> for ExecutionResult<R, E>

Source

impl<R, I> IntoInner<I> for ExecutionResponse<R>
where R: Into<I>,