pub struct ConnectionPool { /* private fields */ }Expand description
ConnectionPool represents pool of connections to DAPI nodes.
It can be cloned and shared between threads. Cloning the pool will create a new reference to the same pool.
Implementations
Sourceimpl ConnectionPool
impl ConnectionPool
Sourcepub fn get(
&self,
prefix: PoolPrefix,
uri: &Uri,
settings: Option<&AppliedRequestSettings>,
) -> Option<PoolItem>
pub fn get( &self, prefix: PoolPrefix, uri: &Uri, settings: Option<&AppliedRequestSettings>, ) -> Option<PoolItem>
Get item from the pool for the given uri and settings.
Arguments
prefix- Prefix for the item in the pool. Used to distinguish between Core and Platform clients.uri- URI of the node.settings- Applied request settings.
Sourcepub fn get_or_create<E>(
&self,
prefix: PoolPrefix,
uri: &Uri,
settings: Option<&AppliedRequestSettings>,
create: impl FnOnce() -> Result<PoolItem, E>,
) -> Result<PoolItem, E>
pub fn get_or_create<E>( &self, prefix: PoolPrefix, uri: &Uri, settings: Option<&AppliedRequestSettings>, create: impl FnOnce() -> Result<PoolItem, E>, ) -> Result<PoolItem, E>
Get value from cache or create it using provided closure.
If value is already in the cache, it will be returned.
If value is not in the cache, it will be created by calling create() and stored in the cache.
Arguments
prefix- Prefix for the item in the pool. Used to distinguish between Core and Platform clients.uri- URI of the node.settings- Applied request settings.
Sourcepub fn put(
&self,
uri: &Uri,
settings: Option<&AppliedRequestSettings>,
value: PoolItem,
)
pub fn put( &self, uri: &Uri, settings: Option<&AppliedRequestSettings>, value: PoolItem, )
Put item into the pool for the given uri and settings.