pub struct RequestSettings {
pub connect_timeout: Option<Duration>,
pub timeout: Option<Duration>,
pub retries: Option<usize>,
pub ban_failed_address: Option<bool>,
pub max_decoding_message_size: Option<usize>,
}Expand description
DAPI request settings.
There are four levels of settings where each next level can override all previous ones:
- Defaults for this library;
- crate::DapiClient settings;
- crate::DapiRequest-specific settings;
- settings for an exact request execution call.
Fields
connect_timeout: Option<Duration>Timeout for establishing a connection.
timeout: Option<Duration>Timeout for single request (soft limit).
Note that the total maximum time of execution can exceed (timeout + connect_timeout) * retries
as it accounts for internal processing time between retries.
retries: Option<usize>Number of retries in case of failed requests. If max retries reached, the last error is returned. 1 means one request and one retry in case of error, etc.
ban_failed_address: Option<bool>Ban DAPI address if node not responded or responded with error.
max_decoding_message_size: Option<usize>Maximum gRPC response size in bytes (decoding limit).
Implementations
Sourceimpl RequestSettings
impl RequestSettings
Sourcepub const fn default() -> Self
pub const fn default() -> Self
Create empty RequestSettings, which means no overrides will be applied.
Actually does the same as Default, but it’s const.
Sourcepub fn override_by(self, rhs: RequestSettings) -> Self
pub fn override_by(self, rhs: RequestSettings) -> Self
Combines two instances of RequestSettings with following rules:
Sourcepub fn finalize(self) -> AppliedRequestSettings
pub fn finalize(self) -> AppliedRequestSettings
Fill in settings defaults.