pub trait CanRetry {
// Required method
fn can_retry(&self) -> bool;
// Provided methods
fn is_no_available_addresses(&self) -> bool { ... }
fn is_node_failure(&self) -> bool { ... }
}Expand description
Returns true if the operation can be retried.
Required Methods
Provided Methods
Sourcefn is_no_available_addresses(&self) -> bool
fn is_no_available_addresses(&self) -> bool
Returns true if this error represents a “no available addresses” condition.
When all addresses have been banned due to errors, the client returns this error. Retry logic uses this to return the last meaningful error instead of this one.
Sourcefn is_node_failure(&self) -> bool
👎Deprecated: Use !can_retry() instead
fn is_node_failure(&self) -> bool
Get boolean flag that indicates if the error is retryable.
Deprecated in favor of CanRetry::can_retry.