pub trait InnerInto<T> {
// Required method
fn inner_into(self) -> T;
}Expand description
Convert inner type without losing additional context information of the wrapper.
Required Methods
Sourcefn inner_into(self) -> T
fn inner_into(self) -> T
Convert inner type without losing additional context information of the wrapper.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".