pub trait IntoInner<T> {
// Required method
fn into_inner(self) -> T;
}Expand description
Unwrap wrapped types
Required Methods
Sourcefn into_inner(self) -> T
fn into_inner(self) -> T
Unwrap the inner type.
This function returns inner type, dropping additional context information. It is lossy operation, so it should be used with caution.