AppliedRequestSettings

Struct AppliedRequestSettings 

pub struct AppliedRequestSettings {
    pub connect_timeout: Option<Duration>,
    pub timeout: Duration,
    pub retries: usize,
    pub ban_failed_address: bool,
    pub max_decoding_message_size: Option<usize>,
    pub ca_certificate: Option<Certificate>,
}
DAPI settings ready to use.

Fields

connect_timeout: Option<Duration>

Timeout for establishing a connection.

timeout: Duration

Timeout for a request.

retries: usize

Number of retries until returning the last error.

ban_failed_address: bool

Ban DAPI address if node not responded or responded with error.

max_decoding_message_size: Option<usize>

Maximum gRPC response size in bytes (decoding limit).

ca_certificate: Option<Certificate>

Certificate Authority certificate to use for verifying the server’s certificate.

Implementations

Source

impl AppliedRequestSettings

pub fn with_ca_certificate(self, ca_cert: Option<Certificate>) -> Self

Use provided CA certificate for verifying the server’s certificate.

If set to None, the system’s default CA certificates will be used.