pub struct AppliedRequestSettings {
pub connect_timeout: Option<Duration>,
pub timeout: Duration,
pub retries: usize,
pub ban_failed_address: bool,
pub max_decoding_message_size: Option<usize>,
pub ca_certificate: Option<Certificate>,
}Expand description
DAPI settings ready to use.
Fields
connect_timeout: Option<Duration>Timeout for establishing a connection.
timeout: DurationTimeout for a request.
retries: usizeNumber of retries until returning the last error.
ban_failed_address: boolBan DAPI address if node not responded or responded with error.
max_decoding_message_size: Option<usize>Maximum gRPC response size in bytes (decoding limit).
ca_certificate: Option<Certificate>Certificate Authority certificate to use for verifying the server’s certificate.
Implementations
Sourceimpl AppliedRequestSettings
impl AppliedRequestSettings
Sourcepub fn with_ca_certificate(self, ca_cert: Option<Certificate>) -> Self
pub fn with_ca_certificate(self, ca_cert: Option<Certificate>) -> Self
Use provided CA certificate for verifying the server’s certificate.
If set to None, the system’s default CA certificates will be used.